% angleBinWidth must be the same angleBinWidth used finding the
% parameter values.
function [distance] = compareSessionAndModel(day, shank, HDcell, session, angleBinWidth, modelParams)

minLength = 100;
minSpikes = 10;

% Create X and Y
[X, Y] = createXY(day, shank, HDcell, angleBinWidth);

% Edit X, Y
[X, Y] = removeShortSessions(X, Y, minLength);
[X, Y] = removeSessionsWithFewSpikes(X, Y, minSpikes);

distance = compareSessionModel(X, session, modelParams.a, modelParams.b, modelParams.c, modelParams.d, modelParams.I, modelParams.q);

% Plot
firingsSession = find(X{session});
duration = length(X{session});
firingsModel = IzhikevichEgen(modelParams.a, modelParams.b, modelParams.c, modelParams.d, modelParams.I, duration);

plotFunction(firingsSession, firingsModel);
end

function distance = compareSessionModel(X, session, a, b, c, d, I, q)

spikeTimesSession = find(X{session});
duration = length(X{session});

spikeTimesModel = IzhikevichEgen(a, b, c, d, I, duration);

% Victor-Purpura 
distance = VictorPurpura(spikeTimesSession, spikeTimesModel, q);

end

function plotFunction(session, model)
    figure
    hold on
    plot(session, ones(length(session)), 'Color', '#0072BD', 'Marker', 'o', 'LineStyle', 'none');
    plot(model, ones(length(model)), 'Color', '#77AC30', 'Marker', '*', 'LineStyle', 'none');
    
    % Legends
    h =  zeros(1,2);
    h(1) = plot(NaN, NaN, 'Color', '#0072BD', 'Marker', 'o', 'DisplayName','Recordings');
    h(2) = plot(NaN, NaN, 'Color', '#77AC30', 'Marker', '*', 'DisplayName','Model');
    legend(h)

    xlabel('Time [ms]')
    
    hold off
    
    set(gcf, 'Units', 'Normalized', 'OuterPosition', [0.3, 0.3, 0.4, 0.31]);
    set(gca,'ytick',[]);
end
