function [s] = compareSessions(day, shank, HDcell, angleBinWidth)
minNoOfSpikes = 10;
minDist = 5; % ms

% dfrStart = 110;
% dfrEnd = 180;

% Create X, Y
[X, Y] = createXY(day, shank, HDcell, angleBinWidth);
[X, Y] = removeSessionsWithFewSpikes(X, Y, minNoOfSpikes);
[X, Y] = sortByLength(X,Y);

% Edit X, Y
% [X, Y] = removeSessionsOutsideDFR(X, Y, dfrStart, dfrEnd);

highestPercentage = 0;
s = {};

for cost = 0.01:0.01:0.01  % Comment out for compareAverageSpikes
    comparisons = 0;    % Total number of comparisons
    noOfSame = 0;       % Number of comparisons of sessions from same angle bin
    noOfDifferent = 0;  % Number of comparisons of sessions from different angle bin
    r = [];             % Comparison yielding the shortest distance. One for same, zero for different. 
    not_ok = {};        % Sessions where it is not possible to compare the session to sessions from both the same and different angle bins

for i = 1:length(Y)-1 
    flag_same = false;
    flag_different = false;
    angleBins = [];
    distances = [];
    for j = i+1:length(Y)
        if (length(X{j})-length(X{i})) <= minDist % Comment out for compareAverageSpikes
            comparisons = comparisons + 1;
            flag_same = Y(i) == Y(j) | flag_same;
            flag_different = ~(Y(i) == Y(j)) | flag_different;
            angleBins(end+1) = Y(i) == Y(j); % Same bin = 1, different = 0
            distances(end+1) = VictorPurpura(X{i},X{j},cost); % Comment out for compareAverageSpikes
%             distances(end+1) = vanRossum(X{i},X{j},cost);
%             distances(end+1) = compareAverageSpikes(X{i},X{j});

        end   % Comment out for compareAverageSpikes
    end
    if flag_same && flag_different
        noOfSame = noOfSame + length(find(angleBins));
        noOfDifferent = noOfDifferent + (length(angleBins)-length(find(angleBins)));
        shortestIdx = find(distances == min(distances));
        if length(shortestIdx) == 1 || length(find(angleBins(shortestIdx))) == length(shortestIdx)
            r(end+1) = angleBins(shortestIdx(1));
        else
            r(end+1) = 0; % If multiple comparisons yield the shortest distance, but not only comparisons from the same angle bin
        end
    else 
        not_ok{end+1} = angleBins;
    end 
end

percentageOfSame = length(find(r))/length(r);

if percentageOfSame > highestPercentage
    optimalCost = cost;
    highestPercentage = percentageOfSame;
end
end     % Comment out for compareAverageSpikes

% Save results in struct
s.cost = optimalCost;
s.percentageOfSame = highestPercentage;
s.noOfSession = length(Y);
s.shortestDistances = r;
s.noOfcomparisons = comparisons;
s.noOfSame = noOfSame;
s.noOfDifferent = noOfDifferent;
end



function d = compareAverageSpikes(session1, session2)

avg1 = length(find(session1))/length(session1);
avg2 = length(find(session2))/length(session2);

d = abs(avg1-avg2);

end
