function [modelParams] = findOptimalModelParameterValues(day, shank, HDcell, session, angleBinWidth)
minLength = 100;
minSpikes = 10;

% Create X, Y
[X, Y] = createXY(day, shank, HDcell, angleBinWidth);

% Edit X, Y
[X, Y] = removeShortSessions(X, Y, minLength);
[X, Y] = removeSessionsWithFewSpikes(X, Y, minSpikes);

shortestDistance = inf;
modelParams = [];

for q = 0.01:0.01:0.01
for I = 1:1:15
for a = 0.02:0.01:0.1
    for b = 0.2:0.01:0.26
        for c = -65:5:-50
            for d = 0.05:0.05:8
                distance = compareSessionModel(X, session, a, b, c, d, I, q);
                if distance < shortestDistance
                    shortestDistance = distance;
                    modelParams.a = a;
                    modelParams.b = b;
                    modelParams.c = c;
                    modelParams.d = d;
                    modelParams.I = I;
                    modelParams.q = q;
                end
            end
        end
    end
end
end
end
modelParams.distance = shortestDistance;

% Plot
firingsSession = find(X{session});
duration = length(X{session});
firingsModel = IzhikevichEgen(modelParams.a, modelParams.b, modelParams.c, modelParams.d, modelParams.I, duration);

plotFunction(firingsSession, firingsModel);
end

function distance = compareSessionModel(X, session, a, b, c, d, I, q)

spikeTimesSession = find(X{session});
duration = length(X{session});

spikeTimesModel = IzhikevichEgen(a, b, c, d, I, duration);

distance = VictorPurpura(spikeTimesSession, spikeTimesModel, q);
end

function plotFunction(session, model)
    figure
    hold on
    plot(session, ones(length(session)), 'Color', '#0072BD', 'Marker', 'o', 'LineStyle', 'none');
    plot(model, ones(length(model)), 'Color', '#A2142F', 'Marker', '*', 'LineStyle', 'none');
    
    % Legends
    h =  zeros(1,2);
    h(1) = plot(NaN, NaN, 'Color', '#0072BD', 'Marker', 'o', 'DisplayName','Recordings');
    h(2) = plot(NaN, NaN, 'Color', '#A2142F', 'Marker', '*', 'DisplayName','Model');
    legend(h)

    xlabel('Time [ms]')
    
    hold off
end
