function [tbs] = timeBetweenSpikes(day, shank, HDcell, angleBinWidth)
[X, Y] = createXY(day, shank, HDcell, angleBinWidth);
[X, Y] = removeSessionsWithFewSpikes(X, Y, 2);

tbs = {};       % Struct

cats = categories(Y);
nums = grp2idx(cats);
for i = 1:length(nums)
    tbs(nums(i)).angleBin = cats(i);
    tbs(nums(i)).time = [];
end

for session = 1:length(X)
    angleBin = Y(session);
    spikes = find(X{session});
    d = [];
    for idx = 1:length(spikes)-1
        d = [d spikes(idx+1)-spikes(idx)];
    end
    
    i = length(tbs(find(cats == angleBin)).time)+1;
    
    tbs(find(cats == angleBin)).time(i).tbs = d;
    tbs(find(cats == angleBin)).time(i).mean = mean(d);
    tbs(find(cats == angleBin)).time(i).sd = std(d);
end

% Find mean of all distancebetween spikes, not mean of mean
tbs_plot_mean = [];
tbs_plot_sd = [];
for angleBin = 1:length(tbs)  
    tbs_angleBin = [];
    for session = 1:length(tbs(angleBin).time)
       tbs_angleBin = [tbs_angleBin tbs(angleBin).time(session).tbs];               
    end
    m = mean(tbs_angleBin);
    s = std(tbs_angleBin);
    
    tbs(angleBin).mean = m;
    tbs(angleBin).sd = s;
    
    tbs_plot_mean = [tbs_plot_mean m];
    tbs_plot_sd = [tbs_plot_sd s];
end

% Plot 
x = NaN(1,360);
y = NaN(1, 360);
for i = 1:length(y)/angleBinWidth
    y1(i*angleBinWidth) = tbs_plot_mean(i);
    y2(i*angleBinWidth) = tbs_plot_sd(i); 
    x(i*angleBinWidth) = i*angleBinWidth;
end



figure
% title(sprintf('Shank: %d, HD cell: %d', shank, HDcell));
title(sprintf('HD cell %s.%d.%d', day(1:6), shank, HDcell));
xlabel('Direction [degrees]');
ylabel('Average time between spikes [ms]');
hold on
plot(x, y1, 'Color', '#0072BD', 'Marker', 'o', 'LineStyle', 'none');
plot(x, y2, 'Color', '#A2142F', 'Marker', '*', 'LineStyle', 'none');
xticks([0:360/8:360])
xlim([0,360])
ylim([0,60])

% Legends
h =  zeros(1,2);
h(1) = plot(NaN, NaN, 'bo', 'DisplayName','Mean', 'Color', '#0072BD', 'Marker', 'o');
h(2) = plot(NaN, NaN, 'g*', 'DisplayName','SD', 'Color', '#A2142F', 'Marker', '*');
legend(h)

hold off

end


